@@ -11,7 +11,7 @@ import threading
 import subprocess
 from elftools.elf.elffile import ELFFile
 from distutils.spawn import find_executable
-from ..settings import MAKEFILENAMES, is_embarc_makefile, is_embarc_base
+from ..settings import MAKEFILENAMES, is_embarc_makefile, is_embarc_base, BUILD_CONFIG_TEMPLATE
 from ..utils import delete_dir_files, generate_json, read_json
 from ..osp import platform
 from ..builder import secureshield
@@ -39,7 +39,7 @@ class embARC_Builder(object):
 
         self.extra_build_opt = buildopts
 
-        self.cache_configs = dict()
+        self.cache_configs = BUILD_CONFIG_TEMPLATE
 
         self.embarc_config = embarc_config
         self.log = "build.log"
@@ -48,30 +48,25 @@ class embARC_Builder(object):
         self.status = "na"
 
     def find_platform(self):
+        if not self.embarc_root:
+            logging.error("unable to determine a supported board")
+            sys.exit(1)
+        self.platform.get_configs(self.source_dir, self.embarc_root)
         if not self.platform.name:
-            if self.cache_configs.get("BOARD", None):
-                self.platform.name = self.cache_configs["BOARD"]
-        if not self.platform.name:
-            if not self.embarc_root:
-                logging.error("unable to determine a supported board")
-                sys.exit(1)
-            else:
-                for file in glob.glob(os.path.join(self.embarc_root, "board", "*", "*.mk")):
-                    try:
-                        self.platform.name = os.path.splitext(os.path.basename(file))[0]
-                        break
-                    except RuntimeError as e:
-                        logging.error("E: failed to find a board. %s" % e)
+            for file in glob.glob(os.path.join(self.embarc_root, "board", "*", "*.mk")):
+                try:
+                    self.platform.name = os.path.splitext(os.path.basename(file))[0]
+                    break
+                except RuntimeError as e:
+                    logging.error("E: failed to find a board. %s" % e)
+        self.platform.get_configs(self.source_dir, self.embarc_root)
         if not self.platform.version:
             if self.cache_configs.get("BD_VER", None):
                 self.platform.version = self.cache_configs["BD_VER"]
-        if not self.platform.version:
-            self.platform.version = self.platform.get_versions(self.source_dir, self.embarc_root)[0]
-        if not self.platform.core:
-            if self.cache_configs.get("CUR_CORE", None):
-                self.platform.core = self.cache_configs["CUR_CORE"]
-        if not self.platform.core:
-            self.platform.core = self.platform.get_cores(self.platform.version, self.source_dir, self.embarc_root)[0]
+            else:
+                self.platform.version = self.platform.supported_versions[0]
+
+        self.platform.core = self.platform.get_cores(self.source_dir, self.platform.version, self.embarc_root)[0]
         logging.info("platform: {}".format(self.platform))
         self.cache_configs["BOARD"] = self.platform.name
         self.cache_configs["BD_VER"] = self.platform.version
@@ -112,8 +107,8 @@ class embARC_Builder(object):
         else:
             os.makedirs(self.build_dir, exist_ok=False)
         self.check_source_dir()
-        logging.info("application: {}".format(self.source_dir))
-        if os.path.exists(self.embarc_config):
+        logging.info("application: {}".format(self.source_dir.replace("\\", "/")))
+        if self.embarc_config and os.path.exists(self.embarc_config):
             logging.info("get cached config from {}".format(self.embarc_config))
             self.cache_configs = read_json(self.embarc_config)
         if self.cache_configs.get("EMBARC_ROOT", None):
@@ -122,7 +117,7 @@ class embARC_Builder(object):
                 logging.info("embARC root: {}".format(self.embarc_root))
         self.cache_configs["EMBARC_ROOT"] = self.embarc_root
         self.find_platform()
-        self.toolchain = self.toolchain or self.cache_configs.get("TOOLCHAIN", None)
+        self.toolchain = self.toolchain or self.platform.configs["'override'"].get("TOOLCHAIN", None)
         if not self.toolchain:
             logging.error("unable to determine build toolchain")
             sys.exit(1)
@@ -229,6 +224,7 @@ class embARC_Builder(object):
             "-C", self.source_dir,
             "OUT_DIR_ROOT=%s" % (self.build_dir)
         ]
+        print(make_opts)
         if self.extra_build_opt:
             make_opts.extend(self.extra_build_opt)
         self.target = target
@@ -381,7 +377,8 @@ class EclipseARC(object):
             sys.exit(1)
         debug_cfg["openocd_bin"] = os.path.join(os.path.dirname(gnu_executable),
                                                 "openocd.exe").replace("\\", "/")
-        debug_cfg["openocd_cfg"] = self.openocd_cfg.replace("\\", "/")
+        if self.builder.platform.name != "nsim":
+            debug_cfg["openocd_cfg"] = self.openocd_cfg.replace("\\", "/")
         return debug_cfg
 
     def generate(self):
@@ -390,16 +387,27 @@ class EclipseARC(object):
         project_cfg["links"] = dict()
         project_cfg["name"] = self.builder.name
         embarc_root = self.builder.embarc_root.replace("\\", "/")
+        build_dir = self.builder.build_dir.replace("\\", "/")
+        source_dir = self.builder.source_dir.replace("\\", "/")
         project_cfg["embarc_root"] = embarc_root
-        if self.builder.source_dir != self.builder.build_dir:
-            project_cfg["source_dir"] = self.builder.source_dir.replace("\\", "/")
+
+        project_cfg["sources"] = dict()
+        for root, _, files in os.walk(source_dir, topdown=False):
+            root = root.replace("\\", "/")
+            if not root.startswith(build_dir):
+                virtual_dir = root.replace(source_dir, "application")
+                project_cfg["sources"][virtual_dir] = list()
+                for f in files:
+                    project_cfg["sources"][virtual_dir].append(
+                        {"name": f, "dir": root}
+                    )
+
         cproject_cfg_include = set()
 
         for include in self.includes:
             if include == embarc_root:
                 continue
             if "embARC_generated" in include:
-                build_dir = self.builder.build_dir.replace("\\", "/")
                 virtual_dir = include.replace(build_dir, "")
                 cproject_cfg_include.add(virtual_dir)
                 continue
@@ -420,29 +428,30 @@ class EclipseARC(object):
                                 {"name": file,
                                  "dir": include.replace(embarc_root, "OSP_ROOT")}
                             )
+
         exporter = Exporter(self.builder.toolchain)
-        logging.info("""Start to generate IDE project accroding to
-                        templates (.project.tmpl and .cproject.tmpl)""")
+        logging.info("generating esclipse project description file ...")
         exporter.gen_file_jinja(
-            "project.tmpl", project_cfg, ".project", self.builder.build_dir
+            "project.tmpl", project_cfg, ".project", build_dir
         )
 
         cproject_cfg = self.get_cproject_cfg()
         cproject_cfg["includes"] = list(cproject_cfg_include)
+        logging.info("generating esclipse cdt into .cproject file ...")
         exporter.gen_file_jinja(
-            ".cproject.tmpl", cproject_cfg, ".cproject", self.builder.build_dir
+            ".cproject.tmpl", cproject_cfg, ".cproject", build_dir
         )
 
         debug_cfg = self.get_debug_cfg()
         debug_cfg["core"] = cproject_cfg["core"]
         debug_cfg["board"] = self.builder.platform.name
         debug_cfg["bd_ver"] = self.builder.platform.version
+        logging.info("generating esclipse launch configuration file ...")
         exporter.gen_file_jinja(
-            ".launch.tmpl", debug_cfg, "%s-%s.launch" % (debug_cfg["name"], self.builder.platform.core), self.builder.build_dir
+            ".launch.tmpl", debug_cfg, "%s-%s.launch" % (debug_cfg["name"], self.builder.platform.core), build_dir
         )
         logging.info(
-            "Open ARC GNU IDE (version) Eclipse \
-            - >File >Open Projects from File System >Paste\n{}".format(
-                self.builder.build_dir
+            "open Eclipse - >File >Open Projects from File System >Paste\n{}".format(
+                build_dir
             )
         )
